[![Documentation Status](https://readthedocs.org/projects/tzk/badge/?version=latest)](https://tzk.readthedocs.io/en/latest/?badge=latest)

**tzk** (*TiddlyZettelKasten*)
    is a TiddlyWiki edition and associated CLI
    for maintaining personal notes
    in something approaching the Zettelkasten method.
It’s updated periodically from whatever tooling I’m currently using
    [in my own Zettelkasten](https://zettelkasten.sorenbjornstad.com).
As such, it’s currently considered alpha-quality;
    while it ought to be very stable and there’s no meaningful risk of data loss,
    updating to a newer version might be difficult
    and I’m unlikely to accept patches
    unless they’re something I want in my own Zettelkasten.
This is intended primarily as a nice starting platform
    on which to build your own tooling.

Some basic knowledge of [TiddlyWiki](https://tiddlywiki.com)
    is necessary and assumed.


Documentation / Installation
============================

Find a live version of the edition on the web with further instructions
    at https://sobjornstad.github.io/tzk/.
You can find the documentation for the CLI
    (which handles creating the wiki,
     versioning with Git,
     and creating public and other derivative versions of the wiki)
    at https://tzk.readthedocs.io/en/latest/.
